summaryrefslogtreecommitdiff
path: root/indra/newview/lltoolpipette.h
diff options
context:
space:
mode:
authorNat Goodspeed <nat@lindenlab.com>2009-06-22 12:52:18 +0000
committerNat Goodspeed <nat@lindenlab.com>2009-06-22 12:52:18 +0000
commitfcaa1ad46fd1df4cfec9dee12caf6e7b5bf32136 (patch)
tree2427269d55e15764ff3cd6511ac7d5729e816869 /indra/newview/lltoolpipette.h
parent844ce9bf885bcc88caa8620cf729061672af3b37 (diff)
QAR-1383: convert new uses of Boost.Signals (arriving from other branches) to
Boost.Signals2 like the rest of the event-system-n code.
Diffstat (limited to 'indra/newview/lltoolpipette.h')
-rw-r--r--indra/newview/lltoolpipette.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/indra/newview/lltoolpipette.h b/indra/newview/lltoolpipette.h
index fcccafe1a4..3b6ebec67e 100644
--- a/indra/newview/lltoolpipette.h
+++ b/indra/newview/lltoolpipette.h
@@ -41,7 +41,7 @@
#include "lltool.h"
#include "lltextureentry.h"
#include <boost/function.hpp>
-#include <boost/signal.hpp>
+#include <boost/signals2.hpp>
class LLViewerObject;
class LLPickInfo;
@@ -58,8 +58,8 @@ public:
virtual BOOL handleHover(S32 x, S32 y, MASK mask);
virtual BOOL handleToolTip(S32 x, S32 y, std::string& msg, LLRect *sticky_rect_screen);
- // Note: Don't return connection; use boost::bind + boost::signal::trackable to disconnect slots
- typedef boost::signal<void (const LLTextureEntry& te)> signal_t;
+ // Note: Don't return connection; use boost::bind + boost::signals2::trackable to disconnect slots
+ typedef boost::signals2::signal<void (const LLTextureEntry& te)> signal_t;
void setToolSelectCallback(const signal_t::slot_type& cb) { mSignal.connect(cb); }
void setResult(BOOL success, const std::string& msg);